pyfigurator
===========

|Build Status| |Coverage Status|

A Python 3 library to make it simpler to implement basic INI configuration and CLI interfaces.

Documentation
-------------

As an alpha release, the documentation of pyfigurator is still a work in progress.

`ReadtheDocs <http://pyfigurator.readthedocs.org/en/latest/>`_

Development Status
------------------

Pyfigurator v0.1 is being considered an "alpha" release, which was more of a proof of concept.  v0.1 is stable, but it
was more of a hacky proof-of-concept design that grew from a single app and then was converted to a standalone package.

v1.0 will be more robust and have a more object oriented approach towards building out configuration
and CLI schemas.  So, bare in mind that the v1.0 release may not be backwards compatible with this release.

.. |Build Status| image:: https://travis-ci.org/Boehemyth/pyfigurator.svg?branch=master
    :target: https://travis-ci.org/boehemyth/pyfigurator
.. |Coverage Status| image:: https://coveralls.io/repos/Boehemyth/pyfigurator/badge.svg?branch=master&service=github
    :target: https://coveralls.io/github/Boehemyth/pyfigurator?branch=master

